@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DateEdit.py 8582 2007-06-18 18:32:39Z rshura $
+# $Id: DateEdit.py 10103 2008-02-24 13:55:55Z acraphae $
 
 """
 Date editing module for GRAMPS. 
@@ -33,15 +33,12 @@ The DateEdit.DateEditor provides a dialog in which the date can be
 unambiguously built using UI controls such as menus and spin buttons.
 """
 
-__author__ = "Donald N. Allingham"
-__version__ = "$Revision: 8582 $"
-
 #-------------------------------------------------------------------------
 #
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+
 
 #-------------------------------------------------------------------------
 #
@@ -49,7 +46,7 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".DateEdit")
+__LOG = logging.getLogger(".DateEdit")
 
 #-------------------------------------------------------------------------
 #
@@ -57,13 +54,15 @@ log = logging.getLogger(".DateEdit")
 #
 #-------------------------------------------------------------------------
 import gtk
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
 # gramps modules
 #
 #-------------------------------------------------------------------------
-from RelLib import Date
+from TransUtils import sgettext as _
+from gen.lib import Date
 import DateHandler
 import const
 import GrampsDisplay
@@ -90,13 +89,15 @@ QUAL_TEXT = (
     (Date.QUAL_CALCULATED, _('Calculated')) )
 
 CAL_TO_MONTHS_NAMES = { 
-    Date.CAL_GREGORIAN  : DateHandler.displayer._MONS,
-    Date.CAL_JULIAN     : DateHandler.displayer._MONS,
-    Date.CAL_HEBREW     : DateHandler.displayer._hebrew,
-    Date.CAL_FRENCH     : DateHandler.displayer._french,
-    Date.CAL_PERSIAN    : DateHandler.displayer._persian,
-    Date.CAL_ISLAMIC    : DateHandler.displayer._islamic }
+    Date.CAL_GREGORIAN  : DateHandler.displayer.MONS,
+    Date.CAL_JULIAN     : DateHandler.displayer.MONS,
+    Date.CAL_HEBREW     : DateHandler.displayer.hebrew,
+    Date.CAL_FRENCH     : DateHandler.displayer.french,
+    Date.CAL_PERSIAN    : DateHandler.displayer.persian,
+    Date.CAL_ISLAMIC    : DateHandler.displayer.islamic }
 
+WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Entering_and_Editing_Data:_Detailed'
+WIKI_HELP_SEC = _('manual|Editing_Dates')
 #-------------------------------------------------------------------------
 #
 # DateEdit
@@ -108,7 +109,7 @@ class DateEdit:
 
     def __init__(self, date_obj, text_obj, button_obj, uistate, track):
         """
-        Creates a connection between the date_obj, text_obj and the pixmap_obj.
+        Create a connection between the date_obj, text_obj and the pixmap_obj.
         Assigns callbacks to parse and change date when the text
         in text_obj is changed, and to invoke Date Editor when the LED
         button_obj is pressed. 
@@ -120,14 +121,14 @@ class DateEdit:
         self.button_obj = button_obj
 
         image = gtk.Image()
-        image.set_from_stock('gramps-date', gtk.ICON_SIZE_BUTTON)
+        image.set_from_stock('gramps-date-edit', gtk.ICON_SIZE_BUTTON)
         self.button_obj.set_image(image)
         self.button_obj.set_relief(gtk.RELIEF_NORMAL)
         self.pixmap_obj = button_obj.get_child()
         
-        self.text_obj.connect('validate',self.validate)
-        self.text_obj.connect('content-changed',self.set_date)
-        self.button_obj.connect('clicked',self.invoke_date_editor)
+        self.text_obj.connect('validate', self.validate)
+        self.text_obj.connect('content-changed', self.set_date)
+        self.button_obj.connect('clicked', self.invoke_date_editor)
         
         self.text_obj.set_text(DateHandler.displayer.display(self.date_obj))
         self.text_obj.validate()
@@ -147,7 +148,7 @@ class DateEdit:
         if self.date_obj.get_modifier() == Date.MOD_TEXTONLY:
             return ValidationError(_('Bad Date'))
 
-    def invoke_date_editor(self,obj):
+    def invoke_date_editor(self, obj):
         """
         Invokes Date Editor dialog when the user clicks the Calendar button.
         If date was in fact built, sets the date_obj to the newly built
@@ -157,7 +158,7 @@ class DateEdit:
         the_date = date_dialog.return_date
         self.update_after_editor(the_date)
 
-    def update_after_editor(self,date_obj):
+    def update_after_editor(self, date_obj):
         """
         Update text entry and validate it
         """
@@ -188,7 +189,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         # Create self.date as a copy of the given Date object.
         self.date = Date(date)
 
-        self.top = gtk.glade.XML(const.gladeFile, "date_edit","gramps" )
+        self.top = glade.XML(const.GLADE_FILE, "date_edit","gramps" )
 
         self.set_window(
             self.top.get_widget('date_edit'),
@@ -200,7 +201,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
             self.calendar_box.append_text(name)
 
         self.calendar_box.set_active(self.date.get_calendar())
-        self.calendar_box.connect('changed',self.switch_calendar)
+        self.calendar_box.connect('changed', self.switch_calendar)
 
         self.quality_box = self.top.get_widget('quality_box')
         for item_number in range(len(QUAL_TEXT)):
@@ -213,7 +214,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
             self.type_box.append_text(MOD_TEXT[item_number][1])
             if self.date.get_modifier() == MOD_TEXT[item_number][0]:
                 self.type_box.set_active(item_number)
-        self.type_box.connect('changed',self.switch_type)
+        self.type_box.connect('changed', self.switch_type)
 
         self.start_month_box = self.top.get_widget('start_month_box')
         self.stop_month_box = self.top.get_widget('stop_month_box')
@@ -262,13 +263,14 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         while True:
             response = self.window.run()
             if response == gtk.RESPONSE_HELP:
-                GrampsDisplay.help('adv-dates')
+                GrampsDisplay.help('adv-dates', webpage=WIKI_HELP_PAGE, 
+                                   section=WIKI_HELP_SEC)
             elif response == gtk.RESPONSE_DELETE_EVENT:
-                return
+                break
             else:
                 if response == gtk.RESPONSE_OK:
-                    (the_quality,the_modifier,the_calendar,
-                     the_value,the_text) = self.build_date_from_ui()
+                    (the_quality, the_modifier, the_calendar,
+                     the_value, the_text) = self.build_date_from_ui()
                     self.return_date = Date(self.date)
                     self.return_date.set(
                         quality=the_quality,
@@ -277,9 +279,12 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
                         value=the_value,
                         text=the_text)
                 self.close()
-                return
+                break
 
     def build_menu_names(self, obj):
+        """
+        Define the menu entry for the ManagedWindows
+        """
         return (_("Date selection"), None)
 
     def build_date_from_ui(self):
@@ -298,12 +303,12 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         text = self.text_entry.get_text()
 
         if modifier == Date.MOD_TEXTONLY:
-            return (Date.QUAL_NONE,Date.MOD_TEXTONLY,Date.CAL_GREGORIAN,
+            return (Date.QUAL_NONE, Date.MOD_TEXTONLY, Date.CAL_GREGORIAN,
                     Date.EMPTY,text)
 
         quality = QUAL_TEXT[self.quality_box.get_active()][0]
 
-        if modifier in (Date.MOD_RANGE,Date.MOD_SPAN):
+        if modifier in (Date.MOD_RANGE, Date.MOD_SPAN):
             value = (
                 self.start_day.get_value_as_int(),
                 self.start_month_box.get_active(),
@@ -320,9 +325,9 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
                 self.start_year.get_value_as_int(),
                 False)
         calendar = self.calendar_box.get_active()
-        return (quality,modifier,calendar,value,text)
+        return (quality, modifier, calendar, value, text)
 
-    def switch_type(self,obj):
+    def switch_type(self, obj):
         """
         Disable/enable various date controls depending on the date 
         type selected via the menu.
@@ -332,7 +337,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         
         # Disable/enable second date controls based on whether
         # the type allows compound dates
-        if the_modifier in (Date.MOD_RANGE,Date.MOD_SPAN):
+        if the_modifier in (Date.MOD_RANGE, Date.MOD_SPAN):
             stop_date_sensitivity = 1
         else:
             stop_date_sensitivity = 0
@@ -348,7 +353,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         self.calendar_box.set_sensitive(date_sensitivity)
         self.quality_box.set_sensitive(date_sensitivity)
 
-    def switch_calendar(self,obj):
+    def switch_calendar(self, obj):
         """
         Change month names and convert the date based on the calendar 
         selected via the menu.
@@ -357,7 +362,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         old_cal = self.date.get_calendar()
         new_cal = self.calendar_box.get_active()
 
-        (the_quality,the_modifier,the_calendar,the_value,the_text) = \
+        (the_quality, the_modifier, the_calendar, the_value, the_text) = \
                                         self.build_date_from_ui()
         self.date.set(
                 quality=the_quality,
