@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_sk.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _Date_sk.py 11298 2008-11-13 08:42:05Z ldnp $
 
 """
 Slovak-specific classes for parsing and displaying dates.
@@ -149,4 +149,4 @@ class DateDisplaySK(DateDisplay):
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(('sk_SK', 'sk', 'SK'), DateParserSK, DateDisplaySK)
+register_datehandler(('sk_SK', 'sk', 'SK', 'Slovak'), DateParserSK, DateDisplaySK)
