@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DbManager.py 10607 2008-04-20 20:58:26Z gburto01 $
+# $Id: DbManager.py 11403 2008-12-03 12:53:32Z bmcage $
 
 """
 Provide the management of databases. This includes opening, renaming,
@@ -44,9 +44,12 @@ import logging
 LOG = logging.getLogger(".DbManager")
 
 if os.sys.platform == "win32":
-    RCS_FOUND = os.system("rcs -V >nul 2>nul") == 0
+    _RCS_FOUND = os.system("rcs -V >nul 2>nul") == 0
+    if _RCS_FOUND and not os.environ.has_key("TZ"):
+        # RCS requires the "TZ" variable be set.
+        os.environ["TZ"] = str(time.timezone)
 else:
-    RCS_FOUND = os.system("rcs -V >/dev/null 2>/dev/null") == 0
+    _RCS_FOUND = os.system("rcs -V >/dev/null 2>/dev/null") == 0
 
 #-------------------------------------------------------------------------
 #
@@ -321,7 +324,7 @@ class DbManager(CLIDbManager):
         self.top.connect('drag_motion', drag_motion)
         self.top.connect('drag_drop', drop_cb)
 
-        if RCS_FOUND:
+        if _RCS_FOUND:
             self.rcs.connect('clicked', self.__rcs)
 
     def __button_press(self, obj, event):
@@ -381,11 +384,11 @@ class DbManager(CLIDbManager):
 
             if store.get_value(node, STOCK_COL) == gtk.STOCK_OPEN:
                 self.connect.set_sensitive(False)
-                if RCS_FOUND:
+                if _RCS_FOUND:
                     self.rcs.show()
             else:
                 self.connect.set_sensitive(not is_rev)
-                if RCS_FOUND and is_rev:
+                if _RCS_FOUND and is_rev:
                     self.rcs.show()
                 else:
                     self.rcs.hide()
@@ -569,7 +572,8 @@ class DbManager(CLIDbManager):
             node = self.model.get_iter(path)
             old_text = self.model.get_value(node, NAME_COL)
             if not old_text.strip() == new_text.strip():
-                if len(path) > 1 :
+                #If there is a ":" in path, then it is a revison
+                if ":" in path :
                     self.__rename_revision(path, new_text)
                 else:
                     self.__rename_database(path, new_text)
@@ -590,7 +594,7 @@ class DbManager(CLIDbManager):
         rev = self.model.get_value(node, PATH_COL)
         archive = os.path.join(db_dir, ARCHIVE_V)
 
-        cmd = [ "rcs", "-m%s:%s" % (rev, new_text), archive ]
+        cmd = [ "rcs", "-x,v", "-m%s:%s" % (rev, new_text), archive ]
 
         proc = subprocess.Popen(cmd, stderr = subprocess.PIPE)
         status = proc.wait()
@@ -743,7 +747,7 @@ class DbManager(CLIDbManager):
         rev = self.data_to_delete[PATH_COL]
         archive = os.path.join(db_dir, ARCHIVE_V)
 
-        cmd = [ "rcs", "-o%s" % rev, "-q", archive ]
+        cmd = [ "rcs", "-x,v", "-o%s" % rev, "-q", archive ]
 
         proc = subprocess.Popen(cmd, stderr = subprocess.PIPE)
         status = proc.wait()
@@ -847,8 +851,7 @@ class DbManager(CLIDbManager):
                                         last, tval, False, ''])
         self.selection.select_iter(node)
         path = self.model.get_path(node)
-        self.dblist.set_cursor(path, focus_column=self.column, 
-                               start_editing=True)
+        self.dblist.set_cursor(path)
         return new_path, title
 
     def __drag_data_received(self, widget, context, xpos, ypos, selection, 
@@ -962,10 +965,10 @@ def find_revisions(name):
     rev  = re.compile("\s*revision\s+([\d\.]+)")
     date = re.compile("date:\s+(\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d)[-+]\d\d;")
 
-    if not os.path.isfile(name):
+    if not os.path.isfile(name) or not _RCS_FOUND:
         return []
 
-    rlog = [ "rlog", "-zLT" , name ]
+    rlog = [ "rlog", "-x,v", "-zLT" , name ]
 
     proc = subprocess.Popen(rlog, stdout = subprocess.PIPE)
     proc.wait()
@@ -1018,8 +1021,8 @@ def check_out(dbase, rev, path, callback):
     Checks out the revision from rcs, and loads the resulting XML file
     into the database.
     """
-    co_cmd   = [ "co", "-q%s" % rev] + [ os.path.join(path, ARCHIVE),
-                                         os.path.join(path, ARCHIVE_V)]
+    co_cmd   = [ "co", "-x,v", "-q%s" % rev] + [ os.path.join(path, ARCHIVE),
+                                                 os.path.join(path, ARCHIVE_V)]
 
     proc = subprocess.Popen(co_cmd, stderr = subprocess.PIPE)
     status = proc.wait()
@@ -1044,8 +1047,9 @@ def check_in(dbase, filename, callback, cursor_func = None):
     """
     Checks in the specified file into RCS
     """
-    init   = [ "rcs", '-i', '-U', '-q', '-t-"GRAMPS database"', ]
-    ci_cmd = [ "ci", "-q", "-f" ]
+    init   = [ "rcs", '-x,v', '-i', '-U', '-q', '-t-"GRAMPS database"' ]
+    ci_cmd = [ "ci", '-x,v', "-q", "-f" ]
+    archive_name = filename + ",v"
 
     glade_xml_file = glade.XML(const.GLADE_FILE, "comment", "gramps")
     top = glade_xml_file.get_widget('comment')
@@ -1055,27 +1059,36 @@ def check_in(dbase, filename, callback, cursor_func = None):
     comment = text.get_text()
     top.destroy()
 
-    if not os.path.isfile(filename + ",v") :
-        proc = subprocess.Popen(init + [filename + ",v"],
+    if not os.path.isfile(archive_name):
+        cmd = init + [archive_name]
+        proc = subprocess.Popen(cmd,
                                 stderr = subprocess.PIPE)
         status = proc.wait()
         message = "\n".join(proc.stderr.readlines())
         proc.stderr.close()
         del proc
+        
+        if status != 0:
+            ErrorDialog(
+                _("Archiving failed"),
+                _("An attempt to create the archive failed "
+                  "with the following message:\n\n%s") % message
+                )
 
     if cursor_func:
         cursor_func(_("Creating data to be archived..."))
     xmlwrite = GrampsDbUtils.XmlWriter(dbase, callback, False, 0)
     xmlwrite.write(filename)
-            
-    cmd = ci_cmd + ['-m%s' % comment, filename, filename + ",v" ]
 
     if cursor_func:
         cursor_func(_("Saving archive..."))
+        
+    cmd = ci_cmd + ['-m%s' % comment, filename, archive_name ]
+    proc = subprocess.Popen(cmd, 
+                            stderr = subprocess.PIPE)
 
-    proc = subprocess.Popen(cmd, stderr = subprocess.PIPE )
-    message = "\n".join(proc.stderr.readlines())
     status = proc.wait()
+    message = "\n".join(proc.stderr.readlines())
     proc.stderr.close()
     del proc
 
