@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _PeopleModel.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _PeopleModel.py 11325 2008-11-21 14:39:16Z ldnp $
 
 """
 TreeModel for the GRAMPS Person tree.
@@ -67,13 +67,6 @@ from Lru import LRU
 
 _CACHE_SIZE = 250
 
-def locale_sort(mylist):
-    """
-    Normal sort routine
-    """
-    l = [ (locale.strxfrm(x),x) for x in mylist ]
-    l.sort()
-    return [ x[1] for x in l ]
 
 class NodeTreeMap:
 
@@ -99,7 +92,9 @@ class NodeTreeMap:
         self.temp_sname_sub = {}
 
     def build_toplevel(self):
-        self.temp_top_path2iter = locale_sort(self.temp_sname_sub.keys())
+        mylist = self.temp_sname_sub.keys()
+        mylist.sort(locale.strcoll)
+        self.temp_top_path2iter = mylist
         for name in self.temp_top_path2iter:
             self.build_sub_entry(name)
 
@@ -196,9 +191,9 @@ class NodeTreeMap:
         return None
 
     def build_sub_entry(self, name):
-        slist = [ (locale.strxfrm(self.sortnames[x]), x) \
+        slist = [ (self.sortnames[x], x) \
                   for x in self.temp_sname_sub[name] ]
-        slist.sort()
+        slist.sort(lambda x, y: locale.strcoll(x[0], y[0]))
 
         val = 0
         for (junk, person_handle) in slist:
