@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _DataEmbedList.py 10108 2008-02-24 18:58:45Z acraphae $
+# $Id: _DataEmbedList.py 11000 2008-08-21 16:42:43Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -62,7 +62,7 @@ class DataEmbedList(EmbeddedList):
         self.obj = obj
         
         EmbeddedList.__init__(self, dbstate, uistate, track, _('_Data'), 
-                              DataModel, move_buttons=True)
+                              DataModel, move_buttons=False)
 
     def build_columns(self):
         EmbeddedList.build_columns(self)
