@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditFamily.py 10108 2008-02-24 18:58:45Z acraphae $
+# $Id: _EditFamily.py 11371 2008-11-30 19:33:46Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -114,7 +114,7 @@ class ChildEmbedList(EmbeddedList):
         Create the object, storing the passed family value
         """
         self.family = family
-        EmbeddedList.__init__(self, dbstate, uistate, track, _('_Children'), 
+        EmbeddedList.__init__(self, dbstate, uistate, track, _('Chil_dren'), 
                               ChildModel, share_button=True, move_buttons=True)
 
     def get_popup_menu_items(self):
@@ -968,10 +968,6 @@ class EditFamily(EditPrimary):
 
             self.db.add_family(self.obj, trans)
             self.db.transaction_commit(trans, _("Add Family"))
-        elif original and self.object_is_empty():
-            trans = self.db.transaction_begin()
-            self.db.remove_family(self.obj.handle, trans)
-            self.db.transaction_commit(trans, _("Remove Family"))
         elif cmp(original.serialize(),self.obj.serialize()):
 
             trans = self.db.transaction_begin()
@@ -1004,7 +1000,7 @@ class EditFamily(EditPrimary):
                 self.db.commit_family(self.obj, trans)
             self.db.transaction_commit(trans, _("Edit Family"))
 
-        self.close()
+        self._do_close()
 
     def _cleanup_on_exit(self):
         (width, height) = self.window.get_size()
