@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2007       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,32 +19,39 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 6521 2006-05-03 01:02:54Z rshura $
+# $Id: __init__.py 9928 2008-01-24 20:38:10Z acraphae $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
 from Filters.Rules._HasEventBase import HasEventBase as HasEvent
 
 from _HasType import HasType
+from _HasMarkerOf import HasMarkerOf
 from _AllEvents import AllEvents
 from _HasIdOf import HasIdOf
 from _RegExpIdOf import RegExpIdOf
 from _HasNoteRegexp import HasNoteRegexp
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
+from _HasReferenceCountOf import HasReferenceCountOf
 from _EventPrivate import EventPrivate
 from _MatchesFilter import MatchesFilter
+from _MatchesPersonFilter import MatchesPersonFilter
+from _MatchesSourceFilter import MatchesSourceFilter
 
 editor_rule_list = [
     AllEvents,
     HasType,
     HasIdOf,
+# TODO: At the time of this writing, the GRAMPS UI does not allow setting markers for events.
+#    HasMarkerOf, 
     RegExpIdOf,
     HasNoteRegexp,
     HasNoteMatchingSubstringOf,
+    HasReferenceCountOf,
     EventPrivate,
     MatchesFilter,
+    MatchesPersonFilter,
+    MatchesSourceFilter,
 ]
