@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2002-2007  Donald N. Allingham
+# Copyright (C) 2007-2008  Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RegExpName.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _RegExpName.py 11303 2008-11-15 10:28:21Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -59,7 +60,7 @@ class RegExpName(Rule):
     def apply(self,db,person):
         for name in [person.get_primary_name()] + person.get_alternate_names():
             for field in [name.first_name, name.surname, name.suffix, name.title,
-                          name.prefix, name.patronymic]:
+                          name.prefix, name.patronymic, name.call]:
                 if self.match.match(field):
                     return True
         else:
