@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SearchFilter.py 7866 2007-01-04 05:09:41Z dallingham $
+# $Id: _SearchFilter.py 9912 2008-01-22 09:17:46Z acraphae $
 
 """
 Package providing filtering framework for GRAMPS.
@@ -30,13 +30,13 @@ class SearchFilter:
         self.text = text.upper()
         self.invert = invert
 
-    def match(self, handle):
+    def match(self, handle, db):
         return self.invert ^ (self.func(handle).upper().find(self.text) != -1)
 
 class ExactSearchFilter(SearchFilter):
     def __init__(self, func, text, invert):
         SearchFilter.__init__(self, func, text, invert)
 
-    def match(self, handle):
+    def match(self, handle, db):
         return self.invert ^ (self.func(handle).upper() == self.text.strip())
     
