@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007-2008  Brian G. Matherly
+# Copyright (C) 2008       Craig J. Anderson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _GuiOptions.py 10179 2008-03-04 12:24:04Z dsblank $
+# $Id: _GuiOptions.py 11339 2008-11-24 03:02:42Z pez4brian $
 
 """
 Specific option handling for a GUI.
@@ -168,12 +169,22 @@ class GuiStringOption(gtk.Entry):
         self.connect('changed', self.__text_changed)
         tooltip.set_tip(self, self.__option.get_help())
         
+        self.__option.connect('avail-changed', self.__update_avail)
+        self.__update_avail()
+
     def __text_changed(self, obj): # IGNORE:W0613 - obj is unused
         """
         Handle the change of the value.
         """
         self.__option.set_value( self.get_text() )
 
+    def __update_avail(self):
+        """
+        Update the availability (sensitivity) of this widget.
+        """
+        avail = self.__option.get_available()
+        self.set_sensitive(avail)
+
 #-------------------------------------------------------------------------
 #
 # GuiColourOption class
@@ -304,13 +315,23 @@ class GuiBooleanOption(gtk.CheckButton):
         self.set_active(self.__option.get_value())
         self.connect('toggled', self.__value_changed)
         tooltip.set_tip(self, self.__option.get_help())
-        
+
+        self.__option.connect('avail-changed', self.__update_avail)
+        self.__update_avail()
+
     def __value_changed(self, obj): # IGNORE:W0613 - obj is unused
         """
         Handle the change of the value.
         """
         self.__option.set_value( self.get_active() )
         
+    def __update_avail(self):
+        """
+        Update the availability (sensitivity) of this widget.
+        """
+        avail = self.__option.get_available()
+        self.set_sensitive(avail)
+
 #-------------------------------------------------------------------------
 #
 # GuiEnumeratedListOption class
@@ -957,7 +978,17 @@ class GuiSurnameColourOption(gtk.HBox):
         self.pack_end(self.vbbox, expand=False)
 
         # populate the surname/colour treeview
-        tmp = self.__option.get_value().split()
+        #
+        # For versions prior to 3.0.2, the fields were delimited with
+        # whitespace.  However, this causes problems when the surname
+        # also has a space within it.  When populating the control,
+        # support both the new and old format -- look for the \xb0
+        # delimiter, and if it isn't there, assume this is the old-
+        # style space-delimited format.  (Bug #2162.)
+        if (self.__option.get_value().find(u'\xb0') >= 0):
+            tmp = self.__option.get_value().split(u'\xb0')
+        else:
+            tmp = self.__option.get_value().split(' ')
         while len(tmp) > 1:
             surname = tmp.pop(0)
             colour = tmp.pop(0)
@@ -975,10 +1006,16 @@ class GuiSurnameColourOption(gtk.HBox):
             surname = self.__model.get_value(i, 0) 
             #surname = surname.encode('iso-8859-1','xmlcharrefreplace')
             colour = self.__model.get_value(i, 1)
-            # tried to use a dictionary, and tried to save it as a tuple,
+            # Tried to use a dictionary, and tried to save it as a tuple,
             # but coulnd't get this to work right -- this is lame, but now
             # the surnames and colours are saved as a plain text string
-            surname_colours += surname + ' ' + colour + ' '
+            #
+            # Hmmm...putting whitespace between the fields causes
+            # problems when the surname has whitespace -- for example,
+            # with surnames like "Del Monte".  So now we insert a non-
+            # whitespace character which is unlikely to appear in
+            # a surname.  (See bug report #2162.)
+            surname_colours += surname + u'\xb0' + colour + u'\xb0'
             i = self.__model.iter_next(i)
         self.__option.set_value( surname_colours )
 
