@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ScratchPad.py 10641 2008-04-26 20:42:31Z gburto01 $
+# $Id: ScratchPad.py 11143 2008-10-14 07:05:06Z erikdrgm $
 
 #------------------------------------------------------------------------
 #
@@ -59,6 +59,13 @@ import ManagedWindow
 from TransUtils import sgettext as _
 
 from DdTargets import DdTargets
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Navigation'
+WIKI_HELP_SEC = _('manual|Using_the_Clipboard')
 
 
 #-------------------------------------------------------------------------
@@ -1245,7 +1252,7 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         
     def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
-        GrampsDisplay.help('tools-util-scratch-pad')
+        GrampsDisplay.help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def on_clear_clicked(self, obj):
         """Deletes the selected object from the object list"""
