@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ODFDoc.py 10496 2008-04-06 03:43:46Z pez4brian $
+# $Id: ODFDoc.py 11419 2008-12-04 21:33:13Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -28,7 +28,10 @@
 #
 #-------------------------------------------------------------------------
 import os
-import md5
+try:
+    from hashlib import md5
+except ImportError:
+    from md5 import md5
 import zipfile
 import time
 import locale
@@ -452,7 +455,7 @@ class ODFDoc(BaseDoc.BaseDoc, BaseDoc.TextDoc, BaseDoc.DrawDoc):
             act_width = x_cm/ratio
             
         not_extension, extension = os.path.splitext(file_name)
-        odf_name = md5.new(file_name).hexdigest() + extension
+        odf_name = md5(file_name).hexdigest() + extension
 
         media_list_item = (file_name, odf_name)
         if not media_list_item in self.media_list:
