@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbdir.py 10487 2008-04-05 22:04:30Z zfoldvar $
+# $Id: dbdir.py 11390 2008-12-02 12:20:40Z dsblank $
 
 """
 Provide the Berkeley DB (DBDir) database backend for GRAMPS.
@@ -480,7 +480,8 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         # These env settings are only needed for Txn environment
         self.env.set_lk_max_locks(25000)
         self.env.set_lk_max_objects(25000)
-        self.env.set_flags(db.DB_LOG_AUTOREMOVE, 1)  # clean up unused logs
+
+        self.set_auto_remove()
 
         # The DB_PRIVATE flag must go if we ever move to multi-user setup
         env_flags = db.DB_CREATE | db.DB_PRIVATE |\
@@ -1556,7 +1557,8 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         transaction = BdbTransaction(msg, self.undodb, batch, no_magic)
         if transaction.batch:
             self.env.txn_checkpoint()
-            self.env.set_flags(db.DB_TXN_NOSYNC, 1)      # async txn
+            if db.version() < (4, 7):
+                self.env.set_flags(db.DB_TXN_NOSYNC, 1)      # async txn
 
             if self.secondary_connected and not transaction.no_magic:
                 # Disconnect unneeded secondary indices
@@ -1594,7 +1596,8 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         self.txn.commit()
         if transaction.batch:
             self.env.txn_checkpoint()
-            self.env.set_flags(db.DB_TXN_NOSYNC, 0)      # sync txn
+            if db.version() < (4, 7):
+                self.env.set_flags(db.DB_TXN_NOSYNC, 0)      # sync txn
 
             if not transaction.no_magic:
                 # create new secondary indices to replace the ones removed
@@ -1687,6 +1690,30 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
 #            self.gramps_upgrade_13()
         print "Upgrade time:", int(time.time()-t), "seconds"
             
+    def set_auto_remove(self):
+        """
+        BSDDB change log settings using new method with renamed attributes
+        """
+        if db.version() < (4, 7):
+            # by the book: old method with old attribute
+            self.env.set_flags(db.DB_LOG_AUTOREMOVE, 1)
+        else: # look at python interface
+            # TODO test with new version of pybsddb
+            try:
+                # try numeric compare, just first 2 digits
+                # this won't work with something like "4.10a", but
+                # hopefully they won't do that
+                old_version = map(int, db.__version__.split(".",2)[:2]) < (4, 7)
+            except:
+                # fallback, weak string compare
+                old_version = db.__version__ < "4.7"
+            if old_version:
+                # undocumented: old method with new attribute
+                self.env.set_flags(db.DB_LOG_AUTO_REMOVE, 1)
+            else:
+                # by the book: new method with new attribute
+                self.env.log_set_config(db.DB_LOG_AUTO_REMOVE, 1)
+
     def write_version(self, name):
         """Write version number for a newly created DB."""
         full_name = os.path.abspath(name)
@@ -1697,7 +1724,9 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         # These env settings are only needed for Txn environment
         self.env.set_lk_max_locks(25000)
         self.env.set_lk_max_objects(25000)
-        self.env.set_flags(db.DB_LOG_AUTOREMOVE, 1)  # clean up unused logs
+
+        # clean up unused logs
+        self.set_auto_remove()
 
         # The DB_PRIVATE flag must go if we ever move to multi-user setup
         env_flags = db.DB_CREATE | db.DB_PRIVATE |\
