@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Desbrowser.py 7815 2006-12-18 22:25:19Z dallingham $
+# $Id: Desbrowser.py 11139 2008-10-11 18:33:56Z erikdrgm $
 
-"Analysis and Exploration/Interactive descendant browser"
+"""Tools/Analysis and Exploration/Interactive Descendant Browser"""
 
 #------------------------------------------------------------------------
 #
@@ -28,7 +28,6 @@
 #
 #------------------------------------------------------------------------
 import os
-from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -36,23 +35,30 @@ from gettext import gettext as _
 #
 #------------------------------------------------------------------------
 import gtk
-import gtk.glade
+from gtk import glade
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import NameDisplay
+from BasicUtils import name_displayer
 from PluginUtils import Tool, register_tool
 import GrampsDisplay
 import ManagedWindow
+from TransUtils import sgettext as _
+#------------------------------------------------------------------------
+#
+# Constants
+#
+#------------------------------------------------------------------------
+WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Tools'
+WIKI_HELP_SEC = _('manual|Interactive_Descendant_Browser...')
+
+
+
+
 
-#------------------------------------------------------------------------
-#
-# 
-#
-#------------------------------------------------------------------------
 class DesBrowse(Tool.ActivePersonTool, ManagedWindow.ManagedWindow):
 
     def __init__(self, dbstate, uistate, options_class, name, callback=None):
@@ -65,14 +71,14 @@ class DesBrowse(Tool.ActivePersonTool, ManagedWindow.ManagedWindow):
         self.active = dbstate.get_active_person()
         self.callback = callback
         self.active_name = _("Descendant Browser: %s") \
-                           % NameDisplay.displayer.display(self.active)
+                           % name_displayer.display(self.active)
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self)
 
         base = os.path.dirname(__file__)
         glade_file = base + os.sep + "desbrowse.glade"
 
-        self.glade = gtk.glade.XML(glade_file,"top","gramps")
+        self.glade = glade.XML(glade_file,"top","gramps")
         self.glade.signal_autoconnect({
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
@@ -92,7 +98,7 @@ class DesBrowse(Tool.ActivePersonTool, ManagedWindow.ManagedWindow):
 
         self.show()
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (self.active_name,_("Descendant Browser tool"))
 
     def make_new_model(self):
@@ -101,15 +107,16 @@ class DesBrowse(Tool.ActivePersonTool, ManagedWindow.ManagedWindow):
         self.add_to_tree(None, None, self.active.get_handle())
         self.tree.expand_all()
 
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
-        GrampsDisplay.help('tools-ae')
+        GrampsDisplay.help('tools-ae',webpage=WIKI_HELP_PAGE, 
+                                   section=WIKI_HELP_SEC)
 
     def add_to_tree(self, parent_id, sib_id, person_handle):
         item_id = self.model.insert_after(parent_id, sib_id)
         person = self.db.get_person_from_handle(person_handle)
         
-        self.model.set(item_id, 0, NameDisplay.displayer.display(person))
+        self.model.set(item_id, 0, name_displayer.display(person))
         self.model.set(item_id, 1, person_handle)
         prev_id = None
         for family_handle in person.get_family_handle_list():
@@ -118,7 +125,7 @@ class DesBrowse(Tool.ActivePersonTool, ManagedWindow.ManagedWindow):
                 prev_id = self.add_to_tree(item_id, prev_id, child_ref.ref)
         return item_id
     
-    def button_press_event(self,obj,event):
+    def button_press_event(self, obj,event):
         from Editors import EditPerson
 
         if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
@@ -143,8 +150,8 @@ class DesBrowseOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        Tool.ToolOptions.__init__(self,name,person_id)
+    def __init__(self, name,person_id=None):
+        Tool.ToolOptions.__init__(self, name,person_id)
 
 #------------------------------------------------------------------------
 #
@@ -157,7 +164,7 @@ register_tool(
     tool_class = DesBrowse,
     options_class = DesBrowseOptions,
     modes = Tool.MODE_GUI,
-    translated_name = _("Interactive descendant browser"),
+    translated_name = _("Interactive Descendant Browser"),
     status = _("Stable"),
     author_name = "Donald N. Allingham",
     author_email = "don@gramps-project.org",
