@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: EventCmp.py 10152 2008-03-01 22:47:48Z pez4brian $
+# $Id: EventCmp.py 11136 2008-10-11 06:41:11Z erikdrgm $
 
 """Tools/Analysis and Exploration/Compare Individual Events"""
 
@@ -29,7 +29,6 @@
 #------------------------------------------------------------------------
 import os
 import sys
-from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -56,10 +55,22 @@ from PluginUtils import Tool, register_tool
 from ReportBase import ReportUtils
 from GrampsDisplay import help
 import ManagedWindow
+from TransUtils import sgettext as _
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+
+
+WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Tools'
+WIKI_HELP_SEC = _('manual|Compare_Individual_Events...')
+
+
 
 #------------------------------------------------------------------------
 #
-# 
+# EventCmp
 #
 #------------------------------------------------------------------------
 class TableReport:
@@ -148,7 +159,7 @@ class EventComparison(Tool.Tool,ManagedWindow.ManagedWindow):
 
     def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
-        help('tools-util')
+        GrampsDisplay.help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def build_menu_names(self, obj):
         return (_("Filter selection"),_("Event Comparison tool"))
