@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExtractCity.py 10152 2008-03-01 22:47:48Z pez4brian $
+# $Id: ExtractCity.py 10888 2008-07-21 02:28:01Z pez4brian $
 
 """Tools/Database Processing/Extract Place Data from a Place Title"""
 
@@ -371,7 +371,7 @@ COLS = [
     (_('Place title'), 1), 
     (_('City'), 2), 
     (_('State'), 3), 
-    (_('Postal code'), 4), 
+    (_('ZIP/Postal Code'), 4), 
     (_('Country'), 5)
     ]
 
