@@ -18,9 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Summary.py 6903 2006-06-16 21:26:44Z dallingham $
+# $Id: Summary.py 10160 2008-03-02 19:18:31Z ldnp $
 
-"View/Summary of the database"
+"""Reports/View/Summary of the Database"""
 
 #------------------------------------------------------------------------
 #
@@ -36,15 +36,16 @@ from gettext import gettext as _
 # GNOME/GTK modules
 #
 #------------------------------------------------------------------------
-import gtk.glade
+from gtk import glade
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import RelLib
+import gen.lib
 from PluginUtils import register_report
+from Utils import media_path_full
 from ReportBase import CATEGORY_VIEW, MODE_GUI
 import DateHandler
 import ManagedWindow
@@ -54,7 +55,7 @@ import ManagedWindow
 # Build the text of the report
 #
 #------------------------------------------------------------------------
-def build_report(database,person):
+def build_report(database):
 
     personList = database.get_person_handles(sort_handles=False)
     familyList = database.get_family_handles()
@@ -66,6 +67,7 @@ def build_report(database,person):
     missing_bday = 0
     males = 0
     females = 0
+    unknowns = 0
     bytes = 0
     namelist = []
     notfound = []
@@ -74,7 +76,8 @@ def build_report(database,person):
     for photo_id in database.get_media_object_handles():
         photo = database.get_object_from_handle(photo_id)
         try:
-            bytes = bytes + posixpath.getsize(photo.get_path())
+            bytes = bytes + posixpath.getsize(media_path_full(database, 
+                                                            photo.get_path()))
         except:
             notfound.append(photo.get_path())
         
@@ -100,10 +103,12 @@ def build_report(database,person):
                 missing_bday = missing_bday + 1
         else:
             missing_bday = missing_bday + 1
-        if person.get_gender() == RelLib.Person.FEMALE:
+        if person.get_gender() == gen.lib.Person.FEMALE:
             females = females + 1
-        else:
+        elif person.get_gender() == gen.lib.Person.MALE:
             males = males + 1
+        else:
+            unknowns += 1
         if name.get_surname() not in namelist:
             namelist.append(name.get_surname())
             
@@ -112,6 +117,7 @@ def build_report(database,person):
     text = text + "%s: %d\n" % (_("Number of individuals"),len(personList))
     text = text + "%s: %d\n" % (_("Males"),males)
     text = text + "%s: %d\n" % (_("Females"),females)
+    text = text + "%s: %d\n" % (_("Individuals with unknown gender"),unknowns)
     text = text + "%s: %d\n" % (_("Individuals with incomplete names"),incomp_names)
     text = text + "%s: %d\n" % (_("Individuals missing birth dates"),missing_bday)
     text = text + "%s: %d\n" % (_("Disconnected individuals"),disconnected)
@@ -141,17 +147,17 @@ def build_report(database,person):
 #
 #------------------------------------------------------------------------
 class SummaryReport(ManagedWindow.ManagedWindow):
-    def __init__(self,dbstate,uistate,person):
+    def __init__(self, dbstate, uistate):
         self.title = _('Database summary')
         ManagedWindow.ManagedWindow.__init__(self,uistate,[],self.__class__)
 
         database = dbstate.db
-        text = build_report(database,person)
+        text = build_report(database)
     
         base = os.path.dirname(__file__)
         glade_file = "%s/summary.glade" % base
 
-        topDialog = gtk.glade.XML(glade_file,"summary","gramps")
+        topDialog = glade.XML(glade_file,"summary","gramps")
         topDialog.signal_autoconnect({
             "destroy_passed_object" : self.close,
         })
@@ -162,7 +168,7 @@ class SummaryReport(ManagedWindow.ManagedWindow):
         textwindow.get_buffer().set_text(text)
         self.show()
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (self.title,None)
 
 #-------------------------------------------------------------------------
@@ -176,8 +182,10 @@ register_report(
     report_class = SummaryReport,
     options_class = None,
     modes = MODE_GUI,
-    translated_name = _("Summary of the database"),
-    status = _("Beta"),
+    translated_name = _("Summary of the Database"),
+    status = _("Stable"),
     description= _("Provides a summary of the current database"),
-    require_active=False,
+    author_name="Brian G. Matherly",
+    author_email="brian@gramps-project.org",
+    require_active=False
     )
