@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2008  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: WritePkg.py 8367 2007-04-09 04:24:06Z pez4brian $
+# $Id: WritePkg.py 10785 2008-06-05 03:43:32Z pez4brian $
 
 "Export to GRAMPS package"
 
@@ -33,6 +33,9 @@ import sys
 import tarfile
 from cStringIO import StringIO
 from gettext import gettext as _
+import ExportOptions
+#from BasicUtils import UpdateCallback
+import gen.proxy
 
 #------------------------------------------------------------------------
 #
@@ -48,28 +51,39 @@ log = logging.getLogger(".WritePkg")
 #
 #-------------------------------------------------------------------------
 import gtk
-import gtk.glade
 
 #-------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from GrampsDb import XmlWriter
-import Utils
-from QuestionDialog import MissingMediaDialog
+from GrampsDbUtils import XmlWriter
 from PluginUtils import register_export
+import Utils
 
 #-------------------------------------------------------------------------
 #
 # writeData
 #
 #-------------------------------------------------------------------------
-def writeData(database,filename,person,callback=None):
-    ret = 0
-    writer = PackageWriter(database,filename,callback)
-    ret = writer.export()
-    return ret
+def writeData(database, filename, person, option_box, callback=None):
+    option_box.parse_options()
+
+    restrict = option_box.restrict
+    private = option_box.private
+
+    if private:
+        database = gen.proxy.PrivateProxyDb(database)
+
+    if restrict:
+        database = gen.proxy.LivingProxyDb(
+            database, gen.proxy.LivingProxyDb.MODE_INCLUDE_LAST_NAME_ONLY)
+
+    if not option_box.cfilter.is_empty():
+        database = gen.proxy.FilterProxyDb(database, option_box.cfilter)
+
+    writer = PackageWriter(database, filename, callback)
+    return writer.export()
     
 #-------------------------------------------------------------------------
 #
@@ -78,13 +92,13 @@ def writeData(database,filename,person,callback=None):
 #-------------------------------------------------------------------------
 class PackageWriter:
 
-    def __init__(self,database,filename,callback):
+    def __init__(self, database, filename, callback=None):
         self.db = database
         self.callback = callback
         self.filename = filename
             
     def export(self):
-        missmedia_action = 0
+#        missmedia_action = 0
         #--------------------------------------------------------------
         def remove_clicked():
             # File is lost => remove all references and the object itself
@@ -140,7 +154,8 @@ class PackageWriter:
                 pass
 
             def fs_ok_clicked(obj):
-                name = Utils.get_unicode_path(fs_top.get_filename())
+                name = unicode(fs_top.get_filename(),
+                               sys.getfilesystemencoding())
                 if os.path.isfile(name):
                     archive.add(name)
 
@@ -158,9 +173,10 @@ class PackageWriter:
         # during the process (i.e. when removing object)
         for m_id in self.db.get_media_object_handles():
             mobject = self.db.get_object_from_handle(m_id)
-            filename = str(mobject.get_path())
+            filename = str(Utils.media_path_full(self.db, mobject.get_path()))
+            archname = str(mobject.get_path())
             if os.path.isfile(filename):
-                archive.add(filename)
+                archive.add(filename, archname)
 #             else:
 #                 # File is lost => ask what to do
 #                 if missmedia_action == 0:
@@ -184,7 +200,7 @@ class PackageWriter:
         
         # Write XML now
         g = StringIO()
-        gfile = XmlWriter(self.db,self.callback,2)
+        gfile = XmlWriter(self.db, self.callback, 2)
         gfile.write_handle(g)
         tarinfo = tarfile.TarInfo('data.gramps')
         tarinfo.size = len(g.getvalue())
@@ -193,11 +209,11 @@ class PackageWriter:
             tarinfo.uid = os.getuid()
             tarinfo.gid = os.getgid()
         g.seek(0)
-        archive.addfile(tarinfo,g)
+        archive.addfile(tarinfo, g)
         archive.close()
         g.close()
 
-        return 1
+        return True
     
 #-------------------------------------------------------------------------
 #
@@ -205,8 +221,9 @@ class PackageWriter:
 #
 #-------------------------------------------------------------------------
 _title = _('GRAM_PS package (portable XML)')
-_description = _('GRAMPS package is an archived XML database together with the media object files.')
-_config = None
+_description = _('GRAMPS package is an archived XML database together '
+                 'with the media object files.')
+_config = (_('GRAMPS package export options'), ExportOptions.WriterOptionBox)
 _filename = 'gpkg'
 
-register_export(writeData,_title,_description,_config,_filename)
+register_export(writeData, _title, _description, _config, _filename)
